@@ -2,7 +2,6 @@ from itertools import count
 from crawlite import BaseCrawler, urlrender
 from crawlite.utils.urls import urljoin
 
-from . import config
 from .extractors import place_detail
 from .payloaders import gen_review_request_payloader
 from .utils import str2date
@@ -10,7 +9,10 @@ from .utils import str2date
 
 COUNT_PER_PAGE = 100
 
-
+config = {
+    'REQUEST_CACHE_BACKEND': 'sqlite',
+    'REQUEST_DELAY': (1, 1.5),
+}
 
 
 class NaverPlaceCrawler(BaseCrawler):
